From: George Spelvin Date: Fri, 31 Jul 2009 14:05:32 GMT Subject: Re: Request for benchmarking: x86 SHA1 code Message-ID: <20090731140532.18327.qmail@science.horizon.com> In-Reply-To: <20090731132702.GY12813@osiris.978.org> > The revised code is faster on Intel Atom N270 by around 15% (results below > typical of several runs): > > $ ./586test ; ./x86test > Result: a9993e36 4706816a ba3e2571 7850c26c 9cd0d89d > Expected:a9993e36 4706816a ba3e2571 7850c26c 9cd0d89d > 500000000 bytes: 4.981760 s > Result: a9993e36 4706816a ba3e2571 7850c26c 9cd0d89d > Expected:a9993e36 4706816a ba3e2571 7850c26c 9cd0d89d > 500000000 bytes: 4.323324 s Cool, thanks! I hadn't optimized it at all for Atom's in-order pipe, so I'm pleasantly surprised.